netapp_ontap.models.s3_bucket_snapshot_restore API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_bucket_snapshot_restore`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3BucketSnapshotRestoreSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3BucketSnapshotRestore object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `objects_remaining: Size GET POST PATCH`

    Remaining objects to be restored for the bucket

  `progress: Size GET POST PATCH`

    Snapshot restore progress in percent

  `snapshot: str GET POST PATCH`

    Name of the snapshot being restored for the bucket

  `state: str GET POST PATCH`

    Snapshot restore state of the bucket

    Valid choices:

    - none
    - preparing
    - restoring
    - done